@@ -378,7 +378,9 @@ class Database:
             auto_timestamp_columns_list = auto_timestamp_columns
 
         keys = list(data.keys())
-        placeholders = ",".join("?" for _ in range(len(keys)))
+        # Profiling revealed that constructing the placeholder string in this fashion
+        # is significantly faster than using ``join``.
+        placeholders = ("?," * len(keys))[:-1]
         values = list(data.values())
 
         extra_columns_list = []
@@ -503,7 +505,7 @@ class Database:
         """
         if isinstance(auto_timestamp_columns, bool):
             if auto_timestamp_columns is True:
-                auto_timestamp_columns_list = self.insert_auto_timestamp_columns
+                auto_timestamp_columns_list = self.update_auto_timestamp_columns
             else:
                 auto_timestamp_columns_list = []
         else:
@@ -678,19 +680,15 @@ class Database:
         """
         # ALTER TABLE ... DROP COLUMN is only supported since SQLite version 3.35, so we
         # implement it by hand here.
-        create_table_statement = self._get_create_table_statement(table_name)
+        table_schema = self.schema[table_name]
         columns = [
-            str(column)
-            for column in create_table_statement.columns
-            if column.name != column_name
+            str(column) for column in table_schema.columns if column.name != column_name
         ]
-        if len(columns) == len(create_table_statement.columns):
+        if len(columns) == len(table_schema.columns):
             raise ColumnDoesNotExistError(table_name, column_name)
 
         select = ", ".join(
-            quote(c.name)
-            for c in create_table_statement.columns
-            if c.name != column_name
+            quote(c.name) for c in table_schema.columns if c.name != column_name
         )
         self._migrate_table(table_name, columns, select=select)
         self.refresh_schema()
@@ -704,10 +702,8 @@ class Database:
             column names must be the same as in the database; otherwise, an exception
             will be raised.
         """
-        create_table_statement = self._get_create_table_statement(table_name)
-        column_map = collections.OrderedDict(
-            (c.name, c) for c in create_table_statement.columns
-        )
+        table_schema = self.schema[table_name]
+        column_map = collections.OrderedDict((c.name, c) for c in table_schema.columns)
 
         if set(column_names) != set(column_map.keys()):
             raise ISqliteError(
@@ -730,10 +726,10 @@ class Database:
         :param new_column: The new definition of the column, without the name, as a SQL
             string.
         """
-        create_table_statement = self._get_create_table_statement(table_name)
+        table_schema = self.schema[table_name]
         columns = []
         altered = False
-        for column in create_table_statement.columns:
+        for column in table_schema.columns:
             if column.name == column_name:
                 columns.append(f"{column_name} {new_column}")
                 altered = True
@@ -746,7 +742,7 @@ class Database:
         self._migrate_table(
             table_name,
             columns,
-            select=", ".join(quote(c.name) for c in create_table_statement.columns),
+            select=", ".join(quote(c.name) for c in table_schema.columns),
         )
         self.refresh_schema()
 
@@ -758,11 +754,12 @@ class Database:
         """
         # ALTER TABLE ... RENAME COLUMN is only supported since SQLite version 3.25, so
         # we implement it by hand here.
-        create_table_statement = self._get_create_table_statement(table_name)
-        columns_before = create_table_statement.columns
+        table_schema = self.schema[table_name]
+
+        columns_before = table_schema.columns
         columns_after = []
         altered = False
-        for column in create_table_statement.columns:
+        for column in table_schema.columns:
             if column.name == old_column_name:
                 columns_after.append(
                     str(rename_column(column, old_column_name, new_column_name))
@@ -975,17 +972,6 @@ class Database:
         # Check that no foreign key constraints have been violated.
         self.sql("PRAGMA foreign_key_check")
 
-    def _get_create_table_statement(
-        self, table_name: str
-    ) -> sqliteparser.ast.CreateTableStatement:
-        sql = self.sql(
-            "SELECT sql FROM sqlite_master WHERE type = 'table' AND name = :table",
-            {"table": table_name},
-            as_tuple=True,
-            multiple=False,
-        )[0]
-        return sqliteparser.parse(sql)[0]
-
     def _get_related_columns_and_joins(
         self, table: str, get_related: Union[List[str], bool]
     ) -> Tuple[str, str]:
